| loglevels | R Documentation |
This list associates names to values and vice versa.
Names and values are the same as in the python standard logging module.
loglevels
An object of class numeric of length 11.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.